import request from '@/utils/request'
// 主数据列表查询
export function getList(data) {
    return request({
        url: '/mdMaintain/logMana/list',
        method: 'post',
        data
    })
}
// 主数据新增
export function addMasterData(data) {
    return request({
        url: '/mdMaintain/logMana/add',
        method: 'post',
        data
    })
}
// 主数据编辑
export function editMasterData(data) {
    return request({
        url: '/mdMaintain/logMana/edit',
        method: 'post',
        data
    })
}
// 主数据批量删除接口
export function removeMasterData(data) {
    return request({
        url: '/mdMaintain/logMana/remove',
        method: 'post',
        data
    })
}
// 主数据批量撤回接口
export function recallMasterData(data) {
    return request({
        url: '/mdMaintain/logMana/recall',
        method: 'post',
        data
    })
}
// 主数据审批日志查询接口
export function getApproveLog(data) {
    return request({
        url: '/mdMaintain/logMana/getApproveLog',
        method: 'post',
        data
    })
}
// 唯一性校验接口
export function uniquenessCheck(data) {
    return request({
        url: '/mdMaintain/logMana/uniquenessCheck',
        method: 'post',
        data
    })
}
// 模版下载
export function gsfwimportTemplate(query) {
    return request({
        url: '/mdMaintain/logMana/mdDataImportTemplate',
        method: 'get',
        params: query
    })
}
// 主数据批量提交接口
export function mdDataBatchSub(data) {
    return request({
        url: '/mdMaintain/logMana/mdDataBatchSub',
        method: 'post',
        data
    })
}
// 主数据变更列表查询
export function changeList(data) {
    return request({
        url: '/mdMaintain/logMana/changeList',
        method: 'post',
        data
    })
}
// 获取模型所有属性接口
export function getAttrByModelId(query) {
    return request({
        url: '/mdMaintain/logMana/getAttrByModelId',
        method: 'get',
        params: query
    })
}

// 通过模型id获取当前主数据类型及目录数据
export function getTreeDataByModelId(data) {
    return request({
        url: '/mdMaintain/logMana/getTreeDataByModelId',
        method: 'post',
        params: data
    })
}
